@@ -55,20 +55,20 @@ static CamelOfflineFolderClass *parent_class = NULL;
 
 static void exchange_expunge (CamelFolder *folder, CamelException *ex);
 static void append_message (CamelFolder *folder, CamelMimeMessage *message,
-			    const CamelMessageInfo *info, char **appended_uid,
+			    const CamelMessageInfo *info, gchar **appended_uid,
 			    CamelException *ex);
 static CamelMimeMessage *get_message         (CamelFolder *folder,
 					      const gchar *uid,
 					      CamelException *ex);
 static GPtrArray      *search_by_expression  (CamelFolder *folder,
-					      const char *exp,
+					      const gchar *exp,
 					      CamelException *ex);
-static guint32 	      count_by_expression  (CamelFolder *folder,
-					      const char *exp,
+static guint32	      count_by_expression  (CamelFolder *folder,
+					      const gchar *exp,
 					      CamelException *ex);
 
 static GPtrArray      *search_by_uids        (CamelFolder *folder,
-					      const char *expression,
+					      const gchar *expression,
 					      GPtrArray *uids,
 					      CamelException *ex);
 static void            transfer_messages_to  (CamelFolder *source,
@@ -85,12 +85,13 @@ static void   transfer_messages_the_hard_way (CamelFolder *source,
 					      CamelException *ex);
 static void refresh_info (CamelFolder *folder, CamelException *ex);
 static void exchange_sync (CamelFolder *folder, gboolean expunge, CamelException *ex);
-static char* get_filename (CamelFolder *folder, const char *uid, CamelException *ex);
+static gchar * get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex);
+static gint cmp_uids (CamelFolder *folder, const gchar *uid1, const gchar *uid2);
 
 static void
 class_init (CamelFolderClass *camel_folder_class)
 {
-	parent_class = CAMEL_OFFLINE_FOLDER_CLASS (camel_type_get_global_classfuncs (camel_offline_folder_get_type ())) ;
+	parent_class = CAMEL_OFFLINE_FOLDER_CLASS (camel_type_get_global_classfuncs (camel_offline_folder_get_type ()));
 
 	/* virtual method definition */
 	camel_folder_class->expunge = exchange_expunge;
@@ -99,6 +100,7 @@ class_init (CamelFolderClass *camel_folder_class)
 	camel_folder_class->search_by_expression = search_by_expression;
 	camel_folder_class->count_by_expression = count_by_expression;
 
+	camel_folder_class->cmp_uids = cmp_uids;
 	camel_folder_class->search_by_uids = search_by_uids;
 	/* use the default function for the search_free */
 	/* camel_folder_class->search_free = search_free; */
@@ -174,16 +176,16 @@ refresh_info (CamelFolder *folder, CamelException *ex)
 
 		camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_REFRESH_FOLDER,
 				 CAMEL_STUB_ARG_FOLDER, folder->full_name,
-			     	 CAMEL_STUB_ARG_END);
+				 CAMEL_STUB_ARG_END);
 	}
-	
+
 	/* sync up the counts now */
 	if (!camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_SYNC_COUNT,
 				 CAMEL_STUB_ARG_FOLDER, folder->full_name,
 				 CAMEL_STUB_ARG_RETURN,
-			      	 CAMEL_STUB_ARG_UINT32, &unread_count,
+				 CAMEL_STUB_ARG_UINT32, &unread_count,
 				 CAMEL_STUB_ARG_UINT32, &visible_count,
-			      	 CAMEL_STUB_ARG_END)){
+				 CAMEL_STUB_ARG_END)){
 		g_print("\n Error syncing up the counts");
 	}
 
@@ -222,12 +224,12 @@ exchange_expunge (CamelFolder *folder, CamelException *ex)
 
 static void
 append_message_data (CamelFolder *folder, GByteArray *message,
-		     const char *subject, const CamelMessageInfo *info,
-		     char **appended_uid, CamelException *ex)
+		     const gchar *subject, const CamelMessageInfo *info,
+		     gchar **appended_uid, CamelException *ex)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (folder);
 	CamelStream *stream_cache;
-	char *new_uid;
+	gchar *new_uid;
 
 	if (!subject)
 		subject = camel_message_info_subject (info);;
@@ -246,7 +248,7 @@ append_message_data (CamelFolder *folder, GByteArray *message,
 						     "cache", new_uid, NULL);
 		if (stream_cache) {
 			camel_stream_write (stream_cache,
-					    (char *) message->data,
+					    (gchar *) message->data,
 					    message->len);
 			camel_stream_flush (stream_cache);
 			camel_object_unref (CAMEL_OBJECT (stream_cache));
@@ -261,15 +263,15 @@ append_message_data (CamelFolder *folder, GByteArray *message,
 
 static void
 append_message (CamelFolder *folder, CamelMimeMessage *message,
-		const CamelMessageInfo *info, char **appended_uid,
+		const CamelMessageInfo *info, gchar **appended_uid,
 		CamelException *ex)
 {
 	CamelStream *stream_mem;
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (folder->parent_store);
 
-	char *old_subject = NULL;
+	gchar *old_subject = NULL;
 	GString *new_subject;
-	int i, len;
+	gint i, len;
 
 	/*
 	   FIXME: We should add a top-level camel API camel_mime_message_prune_invalid_chars
@@ -317,7 +319,7 @@ fix_broken_multipart_related (CamelMimePart *part)
 	CamelDataWrapper *content;
 	CamelMultipart *multipart, *new;
 	CamelMimePart *subpart;
-	int i, count, broken_parts;
+	gint i, count, broken_parts;
 
 	content = camel_medium_get_content_object (CAMEL_MEDIUM (part));
 
@@ -364,8 +366,8 @@ fix_broken_multipart_related (CamelMimePart *part)
 	}
 }
 
-static char*
-get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
+static gchar *
+get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (folder);
 
@@ -373,7 +375,7 @@ get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
 }
 
 static GByteArray *
-get_message_data (CamelFolder *folder, const char *uid, CamelException *ex)
+get_message_data (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (folder);
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (folder->parent_store);
@@ -413,7 +415,7 @@ get_message_data (CamelFolder *folder, const char *uid, CamelException *ex)
 		return NULL;
 	}
 
-	camel_stream_write (stream, (char *) ba->data, ba->len);
+	camel_stream_write (stream, (gchar *) ba->data, ba->len);
 	camel_stream_flush (stream);
 	camel_object_unref (CAMEL_OBJECT (stream));
 
@@ -423,7 +425,7 @@ get_message_data (CamelFolder *folder, const char *uid, CamelException *ex)
 #define MAILING_LIST_HEADERS "X-MAILING-LIST X-LOOP LIST-ID LIST-POST MAILING-LIST ORIGINATOR X-LIST RETURN-PATH X-BEENTHERE "
 
 static CamelMimeMessage *
-get_message (CamelFolder *folder, const char *uid, CamelException *ex)
+get_message (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (folder);
 	CamelMimeMessage *msg;
@@ -455,7 +457,7 @@ get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	if(camel_medium_get_header (CAMEL_MEDIUM (msg), "Sender")) {
 		list_headers = g_strsplit (MAILING_LIST_HEADERS, " ", 0);
 		if (list_headers) {
-			int i = 0;
+			gint i = 0;
 			while (list_headers[i]) {
 				if (camel_medium_get_header (CAMEL_MEDIUM (msg), list_headers[i])) {
 					found_list = TRUE;
@@ -475,7 +477,7 @@ get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 }
 
 static GPtrArray *
-search_by_expression (CamelFolder *folder, const char *expression,
+search_by_expression (CamelFolder *folder, const gchar *expression,
 		      CamelException *ex)
 {
 	CamelFolderSearch *search;
@@ -491,7 +493,7 @@ search_by_expression (CamelFolder *folder, const char *expression,
 }
 
 static guint32
-count_by_expression (CamelFolder *folder, const char *expression,
+count_by_expression (CamelFolder *folder, const gchar *expression,
 		      CamelException *ex)
 {
 	CamelFolderSearch *search;
@@ -506,9 +508,17 @@ count_by_expression (CamelFolder *folder, const char *expression,
 	return matches;
 }
 
+static gint
+cmp_uids (CamelFolder *folder, const gchar *uid1, const gchar *uid2)
+{
+	g_return_val_if_fail (uid1 != NULL, 0);
+	g_return_val_if_fail (uid2 != NULL, 0);
+
+	return strcmp (uid1, uid2);
+}
 
 static GPtrArray *
-search_by_uids (CamelFolder *folder, const char *expression,
+search_by_uids (CamelFolder *folder, const gchar *expression,
 		GPtrArray *uids, CamelException *ex)
 {
 	CamelFolderSearch *search;
@@ -534,8 +544,8 @@ transfer_messages_the_hard_way (CamelFolder *source, GPtrArray *uids,
 	CamelException local_ex;
 	CamelMessageInfo *info;
 	GByteArray *ba;
-	char *ret_uid;
-	int i;
+	gchar *ret_uid;
+	gint i;
 
 	if (transferred_uids)
 		*transferred_uids = g_ptr_array_new ();
@@ -584,10 +594,10 @@ cache_xfer (CamelExchangeFolder *stub_source, CamelExchangeFolder *stub_dest,
 	    GPtrArray *src_uids, GPtrArray *dest_uids, gboolean delete)
 {
 	CamelStream *src, *dest;
-	int i;
+	gint i;
 
 	for (i = 0; i < src_uids->len; i++) {
-		if (!*(char *)dest_uids->pdata[i])
+		if (!*(gchar *)dest_uids->pdata[i])
 			continue;
 
 		src = camel_data_cache_get (stub_source->cache, "cache",
@@ -620,7 +630,7 @@ transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (source->parent_store);
 	CamelMessageInfo *info;
 	GPtrArray *ret_uids = NULL;
-	int hier_len, i;
+	gint hier_len, i;
 
 	camel_operation_start (NULL, delete_originals ? _("Moving messages") :
 			       _("Copying messages"));
@@ -648,7 +658,7 @@ transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 				break;
 		}
 		goto end;
- 	}
+	}
 
 
 	hier_len = strcspn (source->full_name, "/");
@@ -674,7 +684,7 @@ transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 		if (transferred_uids)
 			*transferred_uids = ret_uids;
 		else {
-			int i;
+			gint i;
 
 			for (i = 0; i < ret_uids->len; i++)
 				g_free (ret_uids->pdata[i]);
@@ -694,7 +704,7 @@ end:
  * base64 representation of this value.
  */
 static CamelSummaryMessageID *
-find_parent (CamelExchangeFolder *exch, const char *thread_index)
+find_parent (CamelExchangeFolder *exch, const gchar *thread_index)
 {
 	CamelSummaryMessageID *msgid;
 	guchar *decoded;
@@ -730,9 +740,9 @@ find_parent (CamelExchangeFolder *exch, const char *thread_index)
  **/
 void
 camel_exchange_folder_add_message (CamelExchangeFolder *exch,
-				   const char *uid, guint32 flags,
-				   guint32 size, const char *headers,
-				   const char *href)
+				   const gchar *uid, guint32 flags,
+				   guint32 size, const gchar *headers,
+				   const gchar *href)
 {
 	CamelFolder *folder = CAMEL_FOLDER (exch);
 	CamelMessageInfo *info;
@@ -802,7 +812,7 @@ camel_exchange_folder_add_message (CamelExchangeFolder *exch,
  **/
 void
 camel_exchange_folder_remove_message (CamelExchangeFolder *exch,
-				      const char *uid)
+				      const gchar *uid)
 {
 	CamelFolderSummary *summary = CAMEL_FOLDER (exch)->summary;
 	CamelFolderChangeInfo *changes;
@@ -847,7 +857,7 @@ camel_exchange_folder_remove_message (CamelExchangeFolder *exch,
  **/
 void
 camel_exchange_folder_uncache_message (CamelExchangeFolder *exch,
-				       const char *uid)
+				       const gchar *uid)
 {
 	camel_data_cache_remove (exch->cache, "cache", uid, NULL);
 }
@@ -863,7 +873,7 @@ camel_exchange_folder_uncache_message (CamelExchangeFolder *exch,
  **/
 void
 camel_exchange_folder_update_message_flags (CamelExchangeFolder *exch,
-					    const char *uid, guint32 flags)
+					    const gchar *uid, guint32 flags)
 {
 	CamelFolder *folder = CAMEL_FOLDER (exch);
 	CamelMessageInfoBase *info;
@@ -899,7 +909,7 @@ camel_exchange_folder_update_message_flags (CamelExchangeFolder *exch,
  **/
 void
 camel_exchange_folder_update_message_flags_ex (CamelExchangeFolder *exch,
-					       const char *uid, guint32 flags,
+					       const gchar *uid, guint32 flags,
 					       guint32 mask)
 {
 	CamelFolder *folder = CAMEL_FOLDER (exch);
@@ -940,9 +950,9 @@ camel_exchange_folder_update_message_flags_ex (CamelExchangeFolder *exch,
  **/
 void
 camel_exchange_folder_update_message_tag (CamelExchangeFolder *exch,
-					  const char *uid,
-					  const char *name,
-					  const char *value)
+					  const gchar *uid,
+					  const gchar *name,
+					  const gchar *value)
 {
 	CamelFolder *folder = CAMEL_FOLDER (exch);
 	CamelMessageInfoBase *info;
@@ -980,19 +990,19 @@ camel_exchange_folder_update_message_tag (CamelExchangeFolder *exch,
  **/
 gboolean
 camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
-				 const char *name, guint32 camel_flags,
-				 const char *folder_dir, int offline_state,
+				 const gchar *name, guint32 camel_flags,
+				 const gchar *folder_dir, gint offline_state,
 				 CamelStub *stub, CamelException *ex)
 {
 	CamelExchangeFolder *exch = (CamelExchangeFolder *)folder;
-	const char *short_name;
-	char *summary_file, *journal_file, *path;
+	const gchar *short_name;
+	gchar *summary_file, *journal_file, *path;
 	GPtrArray *summary, *uids, *hrefs;
 	GByteArray *flags;
 	guint32 folder_flags;
 	CamelMessageInfo *info;
 	CamelExchangeMessageInfo *einfo;
-	int i, len = 0;
+	gint i, len = 0;
 
 	short_name = strrchr (name, '/');
 	if (!short_name++)
@@ -1109,7 +1119,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 
 		if (offline_state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL )
 			return TRUE;
-		
+
 		if (len)
 			return TRUE;
 
