@@ -57,8 +57,8 @@ GSList                 *exchange_config_listener_get_accounts (ExchangeConfigLis
 
 void			exchange_config_listener_migrate_esources (ExchangeConfigListener *config_listener);
 
-void 			add_folder_esource (ExchangeAccount *account, FolderType folder_type, const char *folder_name, const char *physical_uri);
-void 			remove_folder_esource (ExchangeAccount *account, FolderType folder_type, const char *physical_uri);
+void			add_folder_esource (ExchangeAccount *account, FolderType folder_type, const gchar *folder_name, const gchar *physical_uri);
+void			remove_folder_esource (ExchangeAccount *account, FolderType folder_type, const gchar *physical_uri);
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
